Solana Operations Interactive Menu
Provides interactive Solana operations using encrypted keystore 提供使用加密 keystore 的交互式 Solana 操作
Enums
- Language
- Language for UI
Functions
- pumpfun_
cashback_ interactive - pumpfun_
sell_ interactive - pumpswap_
cashback_ interactive - pumpswap_
sell_ interactive - show_
operations_ menu - Placeholder for non-solana-ops builds
- show_
solana_ operations_ menu - Entry point for Solana operations from interactive menu Prompts for keystore file and password, then shows operations menu